==> scanbot_sdk-2.0.1.tar.gz: ios/Classes/Extensions/SDK/Scanner Configuration/SBSDKUIDocumentScannerUIConfiguration.swift <==
//
//  SBSDKUIDocumentScannerUIConfiguration.swift
//  Runner
//
//  Created by Zhenya Knizhnik on 22.08.19.
//  Copyright © 2019 The Chromium Authors. All rights reserved.
//

import Foundation
import ScanbotSDK

extension SBSDKUIDocumentScannerUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarButtonsInactiveColor"] as? String {
            self.topBarButtonsInactiveColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarButtonsActiveColor"] as? String {
            self.topBarButtonsActiveColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonBackgroundColor"] as? String {
            self.polygonBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonBackgroundColorOK"] as? String {
            self.polygonBackgroundColorOK = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonColor"] as? String {
            self.polygonColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonColorOK"] as? String {
            self.polygonColorOK = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["cameraBackgroundColor"] as? String {
            self.cameraBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomBarBackgroundColor"] as? String {
            self.bottomBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomBarButtonsColor"] as? String {
            self.bottomBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonIndicatorColor"] as? String {
            self.shutterButtonIndicatorColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonManualInnerColor"] as? String {
            self.shutterButtonManualInnerColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonManualOuterColor"] as? String {
            self.shutterButtonManualOuterColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonAutoInnerColor"] as? String {
            self.shutterButtonAutoInnerColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonAutoOuterColor"] as? String {
            self.shutterButtonAutoOuterColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["userGuidanceBackgroundColor"] as? String {
            self.userGuidanceBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["userGuidanceTextColor"] as? String {
            self.userGuidanceTextColor = UIColor(hexString: hex)
        }
        
        if let isShutterButtonHidden = dictionary["shutterButtonHidden"] as? Bool {
            self.isShutterButtonHidden = isShutterButtonHidden
        }
        
        if let isMultiPageButtonHidden = dictionary["multiPageButtonHidden"] as? Bool {
            self.isMultiPageButtonHidden = isMultiPageButtonHidden
        }
        
        if let isFlashImageButtonHidden = dictionary["flashImageButtonHidden"] as? Bool {
            self.isFlashImageButtonHidden = isFlashImageButtonHidden
        }
        
        if let isCancelButtonHidden = dictionary["cancelButtonHidden"] as? Bool {
            self.isCancelButtonHidden = isCancelButtonHidden
        }
        
        if let isAutoSnappingButtonHidden = dictionary["autoSnappingButtonHidden"] as? Bool {
            self.isAutoSnappingButtonHidden = isAutoSnappingButtonHidden
        }
        
        if let polygonLineWidth = dictionary["polygonLineWidth"] as? CGFloat {
            self.polygonLineWidth = polygonLineWidth
        }
    }
}

==> scanbot_sdk-2.4.1.tar.gz: ios/Classes/Extensions/SDK/Scanner Configuration/SBSDKUIDocumentScannerUIConfiguration.swift <==
//
//  SBSDKUIDocumentScannerUIConfiguration.swift
//  Runner
//
//  Created by Zhenya Knizhnik on 22.08.19.
//  Copyright © 2019 The Chromium Authors. All rights reserved.
//

import Foundation
import ScanbotSDK

extension SBSDKUIDocumentScannerUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarButtonsInactiveColor"] as? String {
            self.topBarButtonsInactiveColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarButtonsActiveColor"] as? String {
            self.topBarButtonsActiveColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonBackgroundColor"] as? String {
            self.polygonBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonBackgroundColorOK"] as? String {
            self.polygonBackgroundColorOK = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonColor"] as? String {
            self.polygonColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonColorOK"] as? String {
            self.polygonColorOK = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["cameraBackgroundColor"] as? String {
            self.cameraBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomBarBackgroundColor"] as? String {
            self.bottomBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomBarButtonsColor"] as? String {
            self.bottomBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonIndicatorColor"] as? String {
            self.shutterButtonIndicatorColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonManualInnerColor"] as? String {
            self.shutterButtonManualInnerColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonManualOuterColor"] as? String {
            self.shutterButtonManualOuterColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonAutoInnerColor"] as? String {
            self.shutterButtonAutoInnerColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["shutterButtonAutoOuterColor"] as? String {
            self.shutterButtonAutoOuterColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["userGuidanceBackgroundColor"] as? String {
            self.userGuidanceBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["userGuidanceTextColor"] as? String {
            self.userGuidanceTextColor = UIColor(hexString: hex)
        }
        
        if let isShutterButtonHidden = dictionary["shutterButtonHidden"] as? Bool {
            self.isShutterButtonHidden = isShutterButtonHidden
        }
        
        if let isMultiPageButtonHidden = dictionary["multiPageButtonHidden"] as? Bool {
            self.isMultiPageButtonHidden = isMultiPageButtonHidden
        }
        
        if let isFlashButtonHidden = dictionary["flashButtonHidden"] as? Bool {
            // TODO property must be renamed in the native SDK: isFlashImageButtonHidden => isFlashButtonHidden
            self.isFlashImageButtonHidden = isFlashButtonHidden
        }
        
        if let isCancelButtonHidden = dictionary["cancelButtonHidden"] as? Bool {
            self.isCancelButtonHidden = isCancelButtonHidden
        }
        
        if let isAutoSnappingButtonHidden = dictionary["autoSnappingButtonHidden"] as? Bool {
            self.isAutoSnappingButtonHidden = isAutoSnappingButtonHidden
        }
        
        if let polygonLineWidth = dictionary["polygonLineWidth"] as? CGFloat {
            self.polygonLineWidth = polygonLineWidth
        }
    }
}
